@@ -24,7 +24,10 @@ package org.apache.bcel.classfile;
 public interface ConstantObject {
 
     /**
-     * @return object representing the constant, e.g., Long for ConstantLong
+     * Gets the object representing the constant, e.g., Long for ConstantLong.
+     *
+     * @param constantPool the constant.
+     * @return object representing the constant, e.g., Long for ConstantLong.
      */
-    Object getConstantValue(ConstantPool cp);
+    Object getConstantValue(ConstantPool constantPool);
 }
