@@ -22,7 +22,7 @@ import org.junit.jupiter.api.Test;
 
 public class IMPDEP2TestCase {
     @Test
-    public void accept() {
+    public void testAccept() {
         final CountingVisitor countVisitor = new CountingVisitor();
         final IMPDEP2 impdep2 = new IMPDEP2();
         impdep2.accept(countVisitor);
